"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllLayersAndTables = void 0;
var tslib_1 = require("tslib");
var helpers_1 = require("./helpers");
var arcgis_rest_request_1 = require("@esri/arcgis-rest-request");
/**
 * ```js
 * import { getAllLayersAndTables } from '@esri/arcgis-rest-feature-layer';
 * getAllLayersAndTables({
 *   url: "https://sampleserver6.arcgisonline.com/arcgis/rest/services/ServiceRequest/FeatureServer/0"
 * })
 *   .then(response) // { layers: [...], tables: [...] }
 * ```
 * Fetches all the layers and tables associated with a given layer service.
 * Wrapper for https://developers.arcgis.com/rest/services-reference/all-layers-and-tables.htm
 *
 * @param options - Request options, including the url for the layer service
 * @returns A Promise that will resolve with the layers and tables for the given service
 */
// TODO: should we expand this to support other valid params of the endpoint?
function getAllLayersAndTables(options) {
    var url = options.url, requestOptions = tslib_1.__rest(options, ["url"]);
    var layersUrl = helpers_1.parseServiceUrl(url) + "/layers";
    return arcgis_rest_request_1.request(layersUrl, requestOptions);
}
exports.getAllLayersAndTables = getAllLayersAndTables;
//# sourceMappingURL=getAllLayersAndTables.js.map